@@ -203,6 +203,7 @@ class Trinket:
             200859: Source.RARE_MOB,  # Seasoned Hunter's Trophy
             198407: Source.WORLD_QUEST,  # Azure Arcanic Amplifier
             198542: Source.WORLD_QUEST,  # Shikaari Huntress' Arrowhead
+            198489: Source.WORLD_QUEST,  # Dreamscape Prism
         }
 
         if self.item_id in item_mapping.keys():
@@ -463,6 +464,7 @@ class Trinket:
             if self.item_id in (
                 198407,
                 198542,
+                198489,
             ):
                 return [Season.SEASON_1]
         # TODO: add more logic to present more trinkets as season trinkets
